/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 02347
 |         WASHINGTON, DC, METROPOLITAN AREA DRUG STUDY(DC*MADS),
 |        1992: DRUG USE AMONG DC WOMEN DELIVERING LIVE BIRTHS IN
 |                              DC HOSPITALS
 |                      (DATASET 0002: MOTHER DATA)
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE spanish   1='(1) SPANISH INTERVIEW ADMINISTERED'
                  2='(2) ENGLISH INTERVIEW ADMINISTERED' ;
  VALUE a_1fffff  1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE xa_1a     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE a_1b      -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE a_1c      -9='(-9) LEGITIMATE SKIP' -6='(-6) MULTIPLE RESPONSE'
                  1='(1) PRIVATE DOCTOR/NURSE-MIDWIFE' 2='(2) HMO'
                  3='(3) HOSPITAL OUTPATIENT CLINIC'
                  4='(4) COMMU/CITY HEALTH DEPT CLINIC' 5='(5) SHELTER CLINIC'
                  6='(6) CLINIC AT SCHOOL/WORK' 7='(7) PRISON/JAIL CLINIC'
                  8='(8) MOBILE OUTREACH TEAM' 9='(9) MILITARY FACILITY'
                  10='(10) HOSPITAL EMERGENCY ROOM' 11='(11) OTHER' ;
  VALUE a_1d_01f  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE a_1d_02f  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE a_1d_03f  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE a_1d_04f  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE a_1d_05f  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE a_1d_06f  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE a_1d_07f  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE a_1d_08f  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE xa_2ffff  -999='(-999) LEGITIMATE SKIP' -888='(-888) MISSING' -444='(-444) DON''T KNOW' ;
  VALUE xa_3ffff  -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE a_4fffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE a4_a_1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW'
                  1='(1) BIRTH CONTROL PILL' 2='(2) DIAPHRAGM' 3='(3) INJECTIONS'
                  4='(4) CONDOM' 5='(5) FOAM/JELLY, CREAM, SUPPOSITORY'
                  6='(6) IUD, COIL, LLP'
                  7='(7) FEMALE STERILIZATION-TUBES TIED/WOMB REMOVED'
                  8='(8) MALE STERILLZATION-VASECTOMY' 9='(9) OTHER' 10='(10) SPONGE'
                  11='(11) RHYTHM' ;
  VALUE a4_a_2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW'
                  1='(1) BIRTH CONTROL PILL' 2='(2) DIAPHRAGM' 3='(3) INJECTIONS'
                  4='(4) CONDOM' 5='(5) FOAM/JELLY, CREAM, SUPPOSITORY'
                  6='(6) IUD, COIL, LLP' 7='(7) FEMALE STERILIZATION-TUBES TIED/WOMB'
                  8='(8) MALE STERILIZATION-VASECTOMY' 9='(9) OTHER' 10='(10) SPONGE'
                  11='(11) RHYTHM' ;
  VALUE a_5fffff  -8='(-8) MISSING' -4='(-4) DON''T KNOW'
                  1='(1) WANTED TO BECOME PREGNANT THAT TIME'
                  2='(2) WANTED TO BECOME PREGNANT LATER'
                  3='(3) WANTED TO BECOME PREGNANT EARLIER'
                  4='(4) DID NOT WANT TO GET PREGNANT' ;
  VALUE a_6fffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE a_6a      -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_01ff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_02ff  -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_03ff  -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_04ff  -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_05ff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_06ff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_07ff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_08ff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_09ff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_10ff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_11ff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_12ff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_7_sp    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 11='(11) ASTHMA OR BRONCHITIS'
                  12='(12) YEAST INFECTION' 13='(13) SINUS PROBLEM' 14='(14) BACK PROBLEMS'
                  15='(15) SICKLE CELL ANEMIA' 16='(16) PLACENTAL PROBLEMS'
                  17='(17) STD, UNSPECIFIED' 18='(18) OVARIAN CYSTS OR FIBROIDS'
                  19='(19) OTHER INFECTIONS' 20='(20) HEART OR BLOOD PROBLEMS'
                  21='(21) ULCER' 22='(22) HERNIA' 23='(23) RUPTURED UTERUS' 24='(24) SEIZURES'
                  25='(25) DEHYDRATION' 26='(26) OTHER' ;
  VALUE a_8_1fff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE a_8a_1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8_2fff  -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8a_2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8_3fff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8a_3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8_4fff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8a_4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8_5fff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8a_5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8_6fff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_8a_6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE a_8_sp    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW'
                  11='(11) TRICHOMONAS' 12='(12) YEAST INFECTION' 13='(13) GENITAL WARTS' ;
  VALUE a_9fffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE a_9_sp    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW'
                  11='(11) AMINOGLYCOSIDES' 12='(12) CEPHALOSPORINS AND PENICILLINS'
                  13='(13) ERYTHROMYCINS AND TETRACYCLINES'
                  14='(14) URINARY/VAGINAL ANTIMICROBIALS' ;
  VALUE a_10ffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE a_10_a    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' ;
  VALUE a_11ffff  -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE a_12ffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' -4='(-4) DON''T KNOW' ;
  VALUE a_13_ft   -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE a_13_in   -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE a_14ffff  -8='(-8) MISSING' ;
  VALUE a_14_a    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' ;
  VALUE a_14_c    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a_15_a    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' ;
  VALUE a_15_b    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' ;
  VALUE a_15_c    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' ;
  VALUE a_15_d    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' ;
  VALUE a17a1_lb  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a1_oz  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE xa17a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -7='(-7) ITEM REFUSAL'
                  -5='(-5) DATA OUT OF RANGE' ;
  VALUE a17a1_mf  -9='(-9) LEGITIMATE SKIP' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a17a1_yn  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a17a2_lb  -9='(-9) LEGITIMATE SKIP' -4='(-4) DON''T KNOW' ;
  VALUE a17a2_oz  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE xa17a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE'
                  -4='(-4) DON''T KNOW' ;
  VALUE a17a2_mf  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a17a2_yn  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a17a3_lb  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a3_oz  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE xa17a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE a17a3_mf  -9='(-9) LEGITIMATE SKIP' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a17a3_yn  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a17a4_lb  -9='(-9) LEGITIMATE SKIP' -4='(-4) DON''T KNOW' ;
  VALUE a17a4_oz  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE xa17a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE'
                  -4='(-4) DON''T KNOW' ;
  VALUE a17a4_mf  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a17a4_yn  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a17a5_lb  -9='(-9) LEGITIMATE SKIP' -4='(-4) DON''T KNOW' ;
  VALUE a17a5_oz  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE xa17a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -4='(-4) DON''T KNOW' ;
  VALUE a17a5_mf  -9='(-9) LEGITIMATE SKIP' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a17a5_yn  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a17a6_lb  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a6_oz  -9='(-9) LEGITIMATE SKIP' -4='(-4) DON''T KNOW' ;
  VALUE xa17a6ff  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a6_mf  -9='(-9) LEGITIMATE SKIP' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a17a6_yn  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE a17a7_lb  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a7_oz  -9='(-9) LEGITIMATE SKIP' ;
  VALUE xa17a7ff  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a7_mf  -9='(-9) LEGITIMATE SKIP' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a17a7_yn  -9='(-9) LEGITIMATE SKIP' 1='(1) YES' 2='(2) NO' ;
  VALUE a17a8_lb  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a8_oz  -9='(-9) LEGITIMATE SKIP' ;
  VALUE xa17a8ff  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a8_mf  -9='(-9) LEGITIMATE SKIP' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a17a8_yn  -9='(-9) LEGITIMATE SKIP' 1='(1) YES' 2='(2) NO' ;
  VALUE a17a9_lb  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a9_oz  -9='(-9) LEGITIMATE SKIP' ;
  VALUE xa17a9ff  -9='(-9) LEGITIMATE SKIP' ;
  VALUE a17a9_mf  -9='(-9) LEGITIMATE SKIP' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a17a9_yn  -9='(-9) LEGITIMATE SKIP' 1='(1) YES' 2='(2) NO' ;
  VALUE xagecalc  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -5='(-5) DATA OUT OF RANGE' ;
  VALUE b_2fffff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -6='(-6) MULTIPLE RESPONSE'
                  1='(1) MARRIED' 2='(2) WIDOWED' 3='(3) DIVORCED/SEPARATED'
                  4='(4) NOT MARRIED/LIVING W/A PARTNER' 5='(5) NEVER MARRIED' ;
  VALUE b_3fffff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' 1='(1) YES' 2='(2) NO' ;
  VALUE b_4fffff  -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE'
                  1='(1) BLACK/AFRICAN AMERICAN' 2='(2) WHITE'
                  3='(3) AMERICAN INDIAN/ALASKAN NATIVE'
                  4='(4) ASIAN/PACIFIC ISLANDER' 5='(5) SOME OTHER RACE'
                  6='(6) HISPANIC,RACE UNSPECIFIED' ;
  VALUE b_5fffff  -8='(-8) MISSING' 0='(0) NO SCHOOLING' 1='(1) ELEMENTARY GRADE 1'
                  2='(2) ELEMENTARY GRADE 2' 3='(3) ELEMENTARY GRADE 3'
                  4='(4) ELEMENTARY GRADE 4' 5='(5) ELEMENTARY GRADE 5'
                  6='(6) ELEMENTARY GRADE 6' 7='(7) ELEMENTARY GRADE 7'
                  8='(8) ELEMENTARY GRADE 8' 9='(9) HIGH SCHOOL GRADE 9'
                  10='(10) HIGH SCHOOL GRADE 10' 11='(11) HIGH SCHOOL GRADE 11'
                  12='(12) HIGH SCHOOL GRADE 12' 13='(13) COLLEGE YEAR 1'
                  14='(14) COLLEGE YEAR 2' 15='(15) COLLEGE YEAR 3' 16='(16) COLLEGE YEAR 4'
                  17='(17) GRADUATE/PROFESSIONAL SCHOOL/HIGHER' ;
  VALUE b_6fffff  -8='(-8) MISSING' -2='(-2) RESPONSE ILLEGIBLE' ;
  VALUE b_7fffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' -4='(-4) DON''T KNOW' ;
  VALUE c_1fffff  -5='(-5) DATA OUT OF RANGE' -4='(-4) DON''T KNOW' 91='(91) NEVER' ;
  VALUE c_2fffff  -8='(-8) MISSING' 91='(91) NEVER SMOKED DAILY' ;
  VALUE c_3fffff  1='(1) WITHIN THE PAST WEEK (7 DAYS)'
                  2='(2) WITHIN THE PAST MONTH (30 DAYS)'
                  3='(3) 1/MORE MON AGO/LESS THAN 3 MON AGO'
                  4='(4) 3/MORE MON AGO/LESS THAN 6 MON AGO'
                  5='(5) 6/MORE MON AGO/LESS THAN 1 YR AGO'
                  6='(6) 1/MORE YR AGO/LESS THAN 3 YR AGO' 7='(7) 3/MORE YEARS AGO'
                  8='(8) EDITED PREGNANCY USE' 9='(9) EDITED LIFETIME USE'
                  91='(91) NEVER SMOKED CIGARETTE IN MY LIFE' ;
  VALUE c_4fffff  1='(1) LESS THAN ONE CIGARETTE A DAY'
                  2='(2) 1 TO 5 CIGARETTES A DAY' 3='(3) ABOUT 1/2 PACK A DAY'
                  4='(4) ABOUT 1 PACK A DAY' 5='(5) ABOUT 1-1/2 PACKS PER DAY'
                  6='(6) ABOUT 2 PACKS OR MORE A DAY'
                  8='(8) EDITED PREGNANCY USE, FREQUENCY UNSPECIFIED'
                  91='(91) DID NOT SMOKE DURING THIS PREGNANCY' ;
  VALUE c_5fffff  -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) YES' 2='(2) NO' ;
  VALUE c_6fffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 91='(91) NEVER' ;
  VALUE c_7fffff  -8='(-8) MISSING' 1='(1) WITHIN THE PAST WEEK (7 DAYS)'
                  2='(2) WITHIN THE PAST WEEK (30 DAYS)'
                  3='(3) 1/MORE MON AGO/LESS THAN 3 MON AGO'
                  4='(4) 3/MORE MON AGO/LESS THAN 6 MON AGO'
                  5='(5) 6/MORE MON AGO/LESS THAN 1 YR AGO'
                  6='(6) 1/MORE YR AGO/LESS THAN 3 YR AGO' 7='(7) 3/MORE YEARS AGO'
                  8='(8) EDITED PREGNANCY USE' 9='(9) EDITED LIFETIME USE'
                  91='(91) NEVER DRANK ALCOHOL IN MY LIFE' ;
  VALUE c_8fffff  -8='(-8) MISSING' 1='(1) DAILY' 2='(2) ALMOST DAILY/3 TO 6 DAYS A WEEK'
                  3='(3) 1 TO 2 DAYS A WEEK' 4='(4) SEVERAL TIMES A MONTH'
                  5='(5) MONTHLY OR LESS(AT LEAST ONCE)'
                  8='(8) EDITED PREGNANCY USE, FREQ UNSPECIFIED'
                  91='(91) DID NOT DRINK ALCO/THIS PREGNANCY' ;
  VALUE c_9fffff  -8='(-8) MISSING' 91='(91) NEVER' ;
  VALUE c_10ffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 91='(91) NEVER' ;
  VALUE c_11ffff  -8='(-8) MISSING' 1='(1) WITHIN THE PAST WEEK (7 DAYS)'
                  2='(2) WITHIN THE PAST WEEK (30 DAYS)'
                  3='(3) 1/MORE MON AGO/LESS THAN 3 MON AGO'
                  4='(4) 3/MORE MON AGO/LESS THAN 6 MON AGO'
                  5='(5) 6/MORE MON AGO/LESS THAN 1 YR AGO'
                  6='(6) 1/MORE YR AGO/LESS THAN 3 YR AGO AGO'
                  7='(7) 3/MORE YEARS AGO' 8='(8) EDITED PREGNANCY USE'
                  9='(9) EDITED LIFETIME USE'
                  91='(91) NEVER USED MARIJUANA/HASH IN LIFE' ;
  VALUE c_12ffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 1='(1) DAILY'
                  2='(2) ALMOST DAILY/3 TO 6 DAYS A WEEK' 3='(3) 1 TO 2 DAYS A WEEK'
                  4='(4) SEVERAL TIMES A MONTH' 5='(5) MONTHLY OR LESS'
                  8='(8) EDITED PREGNANCY USE, FREQUENCY'
                  91='(91) NOT USED MARIJUANA/THIS PREGNANCY' ;
  VALUE c_13ffff  -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) YES' 2='(2) NO' ;
  VALUE c_14ffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 91='(91) NEVER' ;
  VALUE c_15ffff  -8='(-8) MISSING' 1='(1) WITHIN THE PAST WEEK (7 DAYS)'
                  2='(2) WITHIN THE PAST MONTH (30 DAYS)'
                  3='(3) 1/MORE MON AGO/LESS THAN 3 MON AGO'
                  4='(4) 3/MORE MON AGO/LESS THAN 6 MON AGO'
                  5='(5) 6/MORE MON AGO/LESS THAN 1 YR AGO'
                  6='(6) 1/MORE YR AGO/LESS THAN 3 YR AGO' 7='(7) 3/MORE YEARS AGO'
                  8='(8) EDITED PREGNANCY USE'
                  91='(91) NEVER USED CRACK COCAINE IN LIFE' ;
  VALUE c_16ffff  -8='(-8) MISSING' 1='(1) DAILY' 2='(2) ALMOST DAILY/3 TO 6 DAYS A WEEK'
                  3='(3) 1 TO 2 DAYS A WEEK' 4='(4) SEVERAL TIMES A MONTH'
                  5='(5) MONTHLY OR LESS'
                  8='(8) EDITED PREGNANCY USE, FREQ UNSPECIFIED'
                  91='(91) NOT USED CRACK COCAINE/THIS PREGNANCY' ;
  VALUE c_17ffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE c_18ffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO'
                  9='(9) LIVE IN HOUSE W/ONE/WHO SMOKED' ;
  VALUE c_19ffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE c_20ffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 91='(91) NEVER' ;
  VALUE c_21ffff  -8='(-8) MISSING' 1='(1) WITHIN THE PAST WEEK (7 DAYS)'
                  2='(2) WITHIN THE PAST WEEK (30 DAYS)'
                  3='(3) 1/MORE MON AGO/LESS THAN 3 MON AGO'
                  4='(4) 3/MORE MON AGO/LESS THAN 6 MON AGO'
                  5='(5) 6/MORE MON AGO/LESS THAN 1 YR AGO'
                  6='(6) 1/MORE YR AGO/LESS THAN 3 YR AGO' 7='(7) 3/MORE YEARS AGO'
                  8='(8) EDITED PREGNANCY USE' 9='(9) EDITED LIFETIME USE'
                  91='(91) NEVER TRIED OTHER COCAINE IN LIFE' ;
  VALUE c_22ffff  -8='(-8) MISSING' 1='(1) DAILY' 2='(2) ALMOST DAILY/3 TO 6 DAYS A WEEK'
                  3='(3) 1 TO 2 DAYS A WEEK' 4='(4) SEVERAL TIMES A MONTH'
                  5='(5) MONTHLY OR LESS'
                  8='(8) EDITED PREGNANCY USE, FREQ UNSPECIFIED'
                  91='(91) NOT USED OTHER COCAINE THIS PREGNANCY' ;
  VALUE c_23ffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 1='(1) YES' 2='(2) NO' ;
  VALUE c_24ffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE c_25ffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 91='(91) NEVER' ;
  VALUE c_26ffff  -8='(-8) MISSING' 1='(1) WITHIN THE PAST WEEK (7 DAYS)'
                  2='(2) WITHIN THE PAST MONTH (30 DAYS)'
                  3='(3) 1/MORE MON AGO/LESS THAN 3 MON AGO'
                  4='(4) 3/MORE MON AGO/LESS THAN 6 MON AGO'
                  5='(5) 6/MORE MON AGO/LESS THAN 1 YR AGO'
                  6='(6) 1/MORE YR AGO/LESS THAN 3 YR AGO' 7='(7) 3/MORE YEARS AGO'
                  8='(8) EDITED PREGNANCY USE' 91='(91) NEVER TRIED HEROIN IN MY LIFE' ;
  VALUE c_27ffff  -8='(-8) MISSING' 1='(1) DAILY' 2='(2) ALMOST DAILY/3 TO 6 DAYS A WEEK'
                  3='(3) 1 TO 2 DAYS A WEEK' 4='(4) SEVERAL TIMES A MONTH'
                  5='(5) MONTHLY OR LESS'
                  8='(8) EDITED PREGNANCY USE, FREQ UNSPECIFIED'
                  91='(91) DID NOT USE HEROIN/THIS PREGNANCY' ;
  VALUE c_28ffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE c_29_01f  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE c_29_02f  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE c_29_03f  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE c_29_04f  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE c_29_05f  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE c_29_91f  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE c_30ffff  -8='(-8) MISSING' 91='(91) NEVER' ;
  VALUE c_31ffff  -8='(-8) MISSING' 1='(1) WITHIN THE PAST WEEK (7 DAYS)'
                  2='(2) WITHIN THE PAST MONTH (30 DAYS)'
                  3='(3) 1/MORE MON AGO/LESS THAN 3 MON AGO'
                  4='(4) 3/MORE MON AGO/LESS THAN 6 MON AGO'
                  5='(5) 6/MORE MON AGO/LESS THAN 1 YR AGO'
                  6='(6) 1/MORE YR AGO/LESS THAN 3 YR AGO' 7='(7) 3/MORE YEARS AGO'
                  8='(8) EDITED PREGNANCY USE' 9='(9) EDITED LIFETIME USE'
                  91='(91) NEVER USED STIMULANT IN MY LIFE' ;
  VALUE c_32ffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE c_33ffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' -2='(-2) RESPONSE ILLEGIBLE'
                  91='(91) NEVER' ;
  VALUE c_34ffff  -8='(-8) MISSING' 1='(1) WITHIN THE PAST WEEK (7 DAYS)'
                  2='(2) WITHIN THE PAST MONTH (30 DAYS)'
                  3='(3) 1/MORE MON AGO/LESS THAN 3 MON AGO'
                  4='(4) 3/MORE MON AGO/LESS THAN 6 MON AGO'
                  5='(5) 6/MORE MON AGO/LESS THAN 1 YR AGP'
                  6='(6) 1/MORE YR AGO/LESS THAN 3 YR AGO' 7='(7) 3/MORE YEARS AGO'
                  91='(91) NEVER USED SEDATIVE IN MY LIFE' ;
  VALUE c_35ffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE d_1_01ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_02ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_03ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_04ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_05ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_06ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_07ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_08ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_09ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_10ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_11ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_12ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_13ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_14ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_15ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_16ff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE d_1_91ff  -8='(-8) MISSING' 0='(0) NOT CIRCLED' 1='(1) CIRCLED' ;
  VALUE d_2fffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE d_3fffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE'
                  1='(1) WITHIN THE PAST WEEK (7 DAYS)'
                  2='(2) WITHIN THE PAST MONTH (30 DAYS)'
                  3='(3) 1/MORE MON AGO/LESS THAN 3 MON AGO'
                  4='(4) 3/MORE MON AGO/LESS THAN 6 MON AGO'
                  5='(5) 6/MORE MON AGO/LESS THAN 1 YR AGO'
                  6='(6) 1/MORE YR AGO/LESS THAN 3 YR AGO' 7='(7) 3/MORE YEARS AGO'
                  91='(91) NEVER USED DRUG W/NEEDLE IN MY LIFE' ;
  VALUE d_4fffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE d_5_a     -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' -4='(-4) DON''T KNOW'
                  1='(1) NO RISK' 2='(2) SLIGHT RISK' 3='(3) MODERATE RISK'
                  4='(4) GREAT RISK' ;
  VALUE d_5_b     -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' -4='(-4) DON''T KNOW'
                  1='(1) NO RISK' 2='(2) SLIGHT RISK' 3='(3) MODERATE RISK'
                  4='(4) GREAT RISK' ;
  VALUE d_5_c     -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' -4='(-4) DON''T KNOW'
                  1='(1) NO RISK' 2='(2) SLIGHT RISK' 3='(3) MODERATE RISK'
                  4='(4) GREAT RISK' ;
  VALUE d_5_d     -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' -4='(-4) DON''T KNOW'
                  1='(1) NO RISK' 2='(2) SLIGHT RISK' 3='(3) MODERATE RISK'
                  4='(4) GREAT RISK' ;
  VALUE d_5_e     -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' -4='(-4) DON''T KNOW'
                  1='(1) NO RISK' 2='(2) SLIGHT RISK' 3='(3) MODERATE RISK'
                  4='(4) GREAT RISK' ;
  VALUE e_1fffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 91='(91) NEVER' ;
  VALUE e_2fffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 1='(1) ALCOHOL PROBLEM'
                  2='(2) DRUG PROBLEM' 3='(3) BOTH'
                  91='(91) NEVER TREATED FOR ALCO/DRUG PROBLEM' ;
  VALUE e_3fffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE e_4fffff  -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) YES' 2='(2) NO' ;
  VALUE f_1_a     -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE f_1_b     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_2_a     -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE f_2_b     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_3_a     -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_3_b     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_4_a     -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_4_b     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_5_a     -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_5_b     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_6_a     -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) YES' 2='(2) NO'
                  3='(3) EDITED YES' ;
  VALUE f_6_b     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO'
                  3='(3) EDITED YES' ;
  VALUE f_7_a     -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_7_b     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_8_a     -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_8_b     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_8_a_a   -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_8_a_b   -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' ;
  VALUE f_9fffff  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' ;
  VALUE f_10ffff  -8='(-8) MISSING' ;
  VALUE g_1fffff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -6='(-6) MULTIPLE RESPONSE'
                  1='(1) BLUE CROSS/BLUE SHIELD' 2='(2) OTHER PRIVATE INSURANCE'
                  3='(3) MEDICAID' 4='(4) STATE/LOCAL GOVERNMENT' 5='(5) CHAMPUS' 6='(6) HMO'
                  7='(7) SELF PAY/NON REFUNDABL BY INSURANCE'
                  8='(8) SOME OTHER SOURCE' 9='(9) DON''T KNOW/UNABLE TO PAY' ;
  VALUE g_2_inco  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW'
                  1='(1) NO INCOME' 2='(2) UNDER $5,000' 3='(3) $5,000-6,300'
                  4='(4) $6,301-$8,450' 5='(5) $8,451-$10,600' 6='(6) $10,601-$12,700'
                  7='(7) $12,701-$14,850' 8='(8) $14,851-$17,000' 9='(9) $17,001-$19,000'
                  10='(10) $19,001-$21,300' 11='(11) $21,301-$25,000'
                  12='(12) $25,001-$30,000' 13='(13) $30,001-$40,000'
                  14='(14) $40,001-$50,000' 15='(15) $50,001-$75,000'
                  16='(16) $75,001 OR MORE' ;
  VALUE g_3_1fff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE g_3_2fff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE g_3_4fff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -6='(-6) MULTIPLE RESPONSE'
                  -4='(-4) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE g_3_5fff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE g_3_6fff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE g_3_7fff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE g_3_8fff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE g_3_9fff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -6='(-6) MULTIPLE RESPONSE'
                  -4='(-4) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE g_3_10ff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE g_3_11ff  -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE g_3_sp    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -7='(-7) ITEM REFUSAL'
                  -4='(-4) DON''T KNOW' 11='(11) INVESTMENTS,STOCKS' 12='(12) WIC'
                  13='(13) DISABILITY' 14='(14) INSURANCE' 15='(15) OTHER' ;
  VALUE h_1fffff  -8='(-8) MISSING' 1='(1) COMPLETED' 2='(2) PARTIAL' ;
  VALUE h_2fffff  -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) HOSPITAL ROOM'
                  2='(2) HALLWAY' 3='(3) LOBBY' 4='(4) CHAPEL' 5='(5) OUTSIDE OF HOSPITAL'
                  6='(6) OTHER' ;
  VALUE h_3fffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE h_4_1fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE h_4_2fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE h_4_3fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE h_4_4fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 0='(0) NOT CIRCLED'
                  1='(1) CIRCLED' ;
  VALUE h_5_a     -8='(-8) MISSING' 1='(1) VERY CONFIDENT' 2='(2) CONFIDENT' 3='(3) UNSURE'
                  4='(4) DOUBTFUL' 5='(5) VERY DOUBTFUL' ;
  VALUE h_5_b     -8='(-8) MISSING' 1='(1) VERY CONFIDENT' 2='(2) CONFIDENT' 3='(3) UNSURE'
                  4='(4) DOUBTFUL' 5='(5) VERY DOUBTFUL' ;
  VALUE h_5_c     -8='(-8) MISSING' 1='(1) VERY CONFIDENT' 2='(2) CONFIDENT' 3='(3) UNSURE'
                  4='(4) DOUBTFUL' 5='(5) VERY DOUBTFUL' ;
  VALUE h_6fffff  -8='(-8) MISSING' 1='(1) YES' 2='(2) NO' 3='(3) EDITED YES' ;
  VALUE h_6_sp    -9='(-9) LEGITIMATE SKIP' -8='(-8) YES'
                  11='(11) INTERVIEWER COMPLETED THE DRUG USE ANSWER SHEETS'
                  12='(12) OTHERS PRESENT DURING THE INTERVIEW'
                  13='(13) DIFFICULT LABOR'
                  14='(14) INDICATION THAT RESPONDENT USED DRUGS'
                  15='(15) BABY ILL (OR DIED)'
                  16='(16) R MAY NOT HAVE UNDERSTOOD THE QUESTIONS'
                  17='(17) MOTHER HAD OTHER MEDICAL/PSYCHOL PROBLEMS'
                  18='(18) R LEERY, RELUCTANT, OR QUESTIONED CONFIDENCE'
                  19='(19) OTHER' ;
  VALUE mcompmn   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' ;
  VALUE xmomage   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' ;
  VALUE m2race    -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) WHITE'
                  2='(2) BLACK/AFRICAN AMERICAN' 3='(3) ASIAN/PACIFIC ISLANDER'
                  4='(4) ALEUT/ESKIMO/AMERICAN INDIAN' 8='(8) OTHER' ;
  VALUE m2_oth    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA'
                  10='(10) LATINO/LATIN AMERICAN' 11='(11) SPANISH' 12='(12) FILIPINO'
                  13='(13) HISPANIC' ;
  VALUE xm3adm    -5='(-5) DATA OUT OF RANGE' -1='(-1) NO ABSTRACT DATA' ;
  VALUE m4pay     -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA'
                  1='(1) PRIVATE INSURANCE/HMO' 2='(2) MEDICAID/MEDICAID HMO'
                  3='(3) SELF-PAID BY PATIENT/RELATIVE'
                  4='(4) STATE OR LOCAL ASSISTANCE' 8='(8) OTHER' ;
  VALUE m5_01a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE m5_02a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE m5_03a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE m5_04a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE m5_05a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE m5_06a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE m5_07a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE m5_08a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE m5_09a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE m5_10a    -9='(-9) LEGITIMATE SKIP' -1='(-1) NO ABSTRACT DATA' 1='(1) 1581'
                  2='(2) 4100' 3='(3) 5419' 4='(4) 7030' 5='(5) 13100' 6='(6) 13102' 7='(7) 23770'
                  8='(8) 25000' 9='(9) 25001' 10='(10) 28260' 11='(11) 30390' 12='(12) 30391'
                  13='(13) 30500' 14='(14) 30510' 15='(15) 30511' 16='(16) 30551' 17='(17) 30561'
                  18='(18) 30590' 19='(19) 30591' 20='(20) 34590' 21='(21) 43101' 22='(22) 47202'
                  23='(23) 49390' 24='(24) 49391' 25='(25) 53390' 26='(26) 57140' 27='(27) 62421'
                  28='(28) 63331' 29='(29) 63492' 30='(30) 63671' 31='(31) 63801' 32='(32) 64001'
                  33='(33) 64111' 34='(34) 64121' 35='(35) 64191' 36='(36) 64201' 37='(37) 64221'
                  38='(38) 64223' 39='(39) 64231' 40='(40) 64232' 41='(41) 64241' 42='(42) 64251'
                  43='(43) 64261' 44='(44) 64271' 45='(45) 64291' 46='(46) 64361' 47='(47) 64381'
                  48='(48) 64401' 49='(49) 64411' 50='(50) 64421' 51='(51) 64501' 52='(52) 64611'
                  53='(53) 64651' 54='(54) 64662' 55='(55) 64671' 56='(56) 64681' 57='(57) 64701'
                  58='(58) 64711' 59='(59) 64721' 60='(60) 64761' 61='(61) 64781' 62='(62) 64782'
                  63='(63) 64791' 64='(64) 64801' 65='(65) 64811' 66='(66) 64831' 67='(67) 64845'
                  68='(68) 64880' 69='(69) 64881' 70='(70) 64891' 71='(71) 64892' 72='(72) 64893'
                  73='(73) 65101' 74='(74) 65211' 75='(75) 65221' 76='(76) 65231' 77='(77) 65241'
                  78='(78) 65251' 79='(79) 65261' 80='(80) 65281' 81='(81) 65291' 82='(82) 65311'
                  83='(83) 65341' 84='(84) 65391' 85='(85) 65401' 86='(86) 65410' 87='(87) 65411'
                  88='(88) 65421' 89='(89) 65441' 90='(90) 65451' 91='(91) 65491' 92='(92) 65531'
                  93='(93) 65611' 94='(94) 65621' 95='(95) 65631' 96='(96) 65651' 97='(97) 65661'
                  98='(98) 65671' 99='(99) 65681' 100='(100) 65721' 101='(101) 65801' 102='(102) 65810'
                  103='(103) 65811' 104='(104) 65821' 105='(105) 65831' 106='(106) 65881' 107='(107) 65901'
                  108='(108) 65910' 109='(109) 65911' 110='(110) 65931' 111='(111) 65941' 112='(112) 65951'
                  113='(113) 65981' 114='(114) 65991' 115='(115) 66001' 116='(116) 66011' 117='(117) 66021'
                  118='(118) 66031' 119='(119) 66041' 120='(120) 66061' 121='(121) 66071' 122='(122) 66091'
                  123='(123) 66101' 124='(124) 66111' 125='(125) 66131' 126='(126) 66201' 127='(127) 66221'
                  128='(128) 66301' 129='(129) 66311' 130='(130) 66321' 131='(131) 66331' 132='(132) 66341'
                  133='(133) 66351' 134='(134) 66361' 135='(135) 66381' 136='(136) 66401' 137='(137) 66411'
                  138='(138) 66414' 139='(139) 66421' 140='(140) 66431' 141='(141) 66451' 142='(142) 66481'
                  143='(143) 66531' 144='(144) 66541' 145='(145) 66551' 146='(146) 66557' 147='(147) 66602'
                  148='(148) 66612' 149='(149) 66622' 150='(150) 66712' 151='(151) 66901' 152='(152) 66922'
                  153='(153) 66951' 154='(154) 66981' 155='(155) 67002' 156='(156) 67101' 157='(157) 67111'
                  158='(158) 67182' 159='(159) 67202' 160='(160) 67412' 161='(161) 69821' 162='(162) 74881'
                  163='(163) 0380X' 164='(164) 0410X' 165='(165) 0411X' 166='(166) 0414X' 167='(167) 0449X'
                  168='(168) 07030' 169='(169) 0781X' 170='(170) 0798X' 171='(171) 0912X' 172='(172) 0970X'
                  173='(173) 0971X' 174='(174) 0979X' 175='(175) 0980X' 176='(176) 1122X' 177='(177) 13101'
                  178='(178) 1310X' 179='(179) 1748X' 180='(180) 1923X' 181='(181) 2181X' 182='(182) 2189X'
                  183='(183) 270XX' 184='(184) 2780X' 185='(185) 2809X' 186='(186) 2825X' 187='(187) 2830X'
                  188='(188) 2851X' 189='(189) 2859X' 190='(190) 2875X' 191='(191) 30520' 192='(192) 30560'
                  193='(193) 3432X' 194='(194) 3439X' 195='(195) 3510X' 196='(196) 4019X' 197='(197) 4240X'
                  198='(198) 4553X' 199='(199) 4556X' 200='(200) 4659X' 201='(201) 5185X' 202='(202) 5282X'
                  203='(203) 5559X' 204='(204) 5680X' 205='(205) 5990X' 206='(206) 6159X' 207='(207) 6160X'
                  208='(208) 6162X' 209='(209) 6202X' 210='(210) 6215X' 211='(211) 6238X' 212='(212) 6245X'
                  213='(213) 6410X' 214='(214) 64661' 215='(215) 64821' 216='(216) 64822' 217='(217) 64841'
                  218='(218) 6500X' 219='(219) 650XX' 220='(220) 65581' 221='(221) 65841' 222='(222) 65921'
                  223='(223) 6600X' 224='(224) 66121' 225='(225) 6620X' 226='(226) 6640X' 227='(227) 6641X'
                  228='(228) 6698X' 229='(229) 67432' 230='(230) 6924X' 231='(231) 6989X' 232='(232) 7088X'
                  233='(233) 7100X' 234='(234) 7293X' 235='(235) 7533X' 236='(236) 7569X' 237='(237) 7807X'
                  238='(238) 7850X' 239='(239) 7856X' 240='(240) 7882X' 241='(241) 7923X' 242='(242) 7958X'
                  243='(243) 9478X' 244='(244) 9952X' 245='(245) 9974X' 246='(246) 9975X' 247='(247) 9981X'
                  248='(248) E9387' 249='(249) V016X' 250='(250) V017X' 251='(251) V018X' 252='(252) V025X'
                  253='(253) V026X' 254='(254) V043X' 255='(255) V072X' 256='(256) V120X' 257='(257) V1581'
                  258='(258) V210X' 259='(259) V233X' 260='(260) V235X' 261='(261) V237X' 262='(262) V238X'
                  263='(263) V240X' 264='(264) V252X' 265='(265) V270X' 266='(266) V272X' 267='(267) V277X'
                  268='(268) V290X' 269='(269) V608X' 270='(270) V615X' ;
  VALUE xm6dis    -1='(-1) NO ABSTRACT DATA' ;
  VALUE m7dispo   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) SENT HOME'
                  2='(2) TRANSFERRED TO OTHER HOSPITAL' 3='(3) MATERNAL DEATH'
                  8='(8) OTHER' ;
  VALUE m8refer   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m8_oth    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA'
                  10='(10) COCAINE' 11='(11) CRACK' ;
  VALUE m9labor   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m10del    -1='(-1) NO ABSTRACT DATA' 1='(1) VAGINAL DELIVERY'
                  2='(2) CESAREAN SECTION, PLANNED'
                  3='(3) CESAREAN SECTION, EMERGENCY'
                  4='(4) CESAREAN SECTION, UNSPECIFIED' 8='(8) OTHER' ;
  VALUE m11anem   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m12ges    -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m13dia    -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m14hrt    -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m15hiv    -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m16hyp    -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m17skl    -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m18std    -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19acaf   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19btob   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19cmar   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19dalc   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19eamp   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19fher   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19gopi   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19hmet   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19icrk   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19jcoc   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m19kpcp   -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m20evid   -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE m21arslt  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA'
                  1='(1) CONFIRMED POSITIVE' 2='(2) NEGATIVE' ;
  VALUE m21brslt  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA'
                  1='(1) CONFIRMED POSITIVE' 2='(2) NEGATIVE' ;
  VALUE m21crslt  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA'
                  1='(1) CONFIRMED POSITIVE' 2='(2) NEGATIVE' ;
  VALUE m21drslt  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA'
                  1='(1) CONFIRMED POSITIVE' 2='(2) NEGATIVE' ;
  VALUE m21erslt  -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA'
                  1='(1) CONFIRMED POSITIVE' 2='(2) NEGATIVE' ;
  VALUE mboxa_af  -1='(-1) NO ABSTRACT DATA' ;
  VALUE mboxa_0f  -8='(-8) MISSING' -1='(-1) NO ABSTRACT DATA' 1='(1) YES' 2='(2) NO' ;
  VALUE mspecpro  -1='(-1) NO ABSTRACT DATA' 1='(1) YES, THERE WERE SPECIAL PROBLEMS'
                  2='(2) NO, THERE AREN''T ANY SPECIAL PROBLEMS' ;
  VALUE m5cntr    -1='(-1) NO ABSTRACT DATA' ;
  VALUE a_educ    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' 1='(1) LESS THAN HIGH SCHOOL'
                  2='(2) HIGH SCHOOL GRADUATE' 3='(3) SOME COLLEGE'
                  4='(4) COLLEGE GRADUATE' ;
  VALUE age       -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -5='(-5) DATA OUT OF RANGE'
                  1='(1) 12-17 YEARS' 2='(2) 18-25 YEARS' 3='(3) 26-34 YEARS'
                  4='(4) 35+ YEARS' ;
  VALUE age_yr    -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -5='(-5) DATA OUT OF RANGE' ;
  VALUE alc_amt   -8='(-8) MISSING' ;
  VALUE alc_amtf  1='(1) NONE' 2='(2) UP TO 0.5 DRINK PER DAY'
                  3='(3) 1/2 TO DRINK PER DAY' 4='(4) UNKNOWN' ;
  VALUE alc_cat   -8='(-8) MISSING' 1='(1) NO ALCOHOL USE DURING PREGNANCY'
                  2='(2) LIGHT ALCOHOL USE DURING PREGNANCY'
                  3='(3) MODERATE/HEAVY ALCOHOL USE DURING PREGNANCY' ;
  VALUE alc_day   -8='(-8) MISSING' ;
  VALUE alcflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE alcmon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE alcpreg   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE alcyr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE anybwg    -8='(-8) MISSING' -4='(-4) DON''T KNOW' 1='(1) NORMAL BIRTHWEIGHT, TERM'
                  2='(2) NORMAL BIRTHWEIGHT, PRETERM' 3='(3) LOW BIRTHWEIGHT, TERM'
                  4='(4) LOW BIRTHWEIGHT, PRETERM' ;
  VALUE anybwt    -8='(-8) MISSING' 1='(1) NORMAL (>= 2500 GRAMS)'
                  2='(2) INTERMEDIATE LBW(>= 1500 & < 2500 GRAMS)'
                  3='(3) VERY LOW (< 1500 GRAMS)' ;
  VALUE anycare   1='(1) ANY PRENATAL CARE' 2='(2) LATE OR NO PRENATAL CARE' ;
  VALUE anyflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE anymon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE anypreg   0='(0) NO' 1='(1) YES' ;
  VALUE anyyr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE av_ethan  -8='(-8) MISSING' 0='(0) LESS THAN 1.00 OUNCE DAILY'
                  1='(1) BETWEEN 1.00 AND 1.99 OUNCES DAILY'
                  2='(2) BETWEEN 2.00 AND 2.99 OUNCES DAILY'
                  3='(3) MORE THAN 3.00 OUNCES DAILY' ;
  VALUE cig_amt   -8='(-8) MISSING' 1='(1) NONE' 2='(2) LESS THAN 1 PACK/DAY'
                  3='(3) 1 PACK/DAY OR MORE' ;
  VALUE cigflag   0='(0) NO' 1='(1) YES' ;
  VALUE cigmon    0='(0) NO' 1='(1) YES' ;
  VALUE cigpreg   0='(0) NO' 1='(1) YES' ;
  VALUE cigyr     0='(0) NO' 1='(1) YES' ;
  VALUE cocflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE cocmon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE cocpreg   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE cocyr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE coo_frq   -8='(-8) MISSING' 1='(1) NONE' 2='(2) LESS THAN WEEKLY'
                  3='(3) WEEKLY OR MORE' ;
  VALUE cooflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE coomon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE coopreg   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE cooyr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE contra    -8='(-8) MISSING' -4='(-4) DON''T KNOW' 1='(1) NONE'
                  2='(2) BIRTH CONTROL PILL' 3='(3) CONDOM' 4='(4) OTHER TYPE' ;
  VALUE crk_frq   -8='(-8) MISSING' 1='(1) NONE' 2='(2) LESS THAN WEEKLY'
                  3='(3) WEEKLY OR MORE' ;
  VALUE crkflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE crkmon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE crkpreg   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE crkyr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE g3_govt   1='(1) ANY GOVERNMENT SOURCE OF INCOME'
                  2='(2) NO GOVERNMENT SOURCE OF INCOME NOTED' ;
  VALUE g3_none   1='(1) NO SOURCE OF INCOME' 2='(2) ANY SOURCE OF INCOME NOTED' ;
  VALUE g3_oth    1='(1) ANY OTHER SOURCE OF INCOME'
                  2='(2) NO OTHER SOURCE OF INCOME NOTED' ;
  VALUE herflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE hermon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE herpreg   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE heryr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE hh_inc    -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -4='(-4) DON''T KNOW'
                  1='(1) UNDER $5,000' 2='(2) $5,000 $10,600' 3='(3) $10,601-$19,000'
                  4='(4) $19,001-$30,000' 5='(5) $30,001-$50,000' 6='(6) OVER $50,000' ;
  VALUE hh_siz1f  -8='(-8) MISSING' -5='(-5) NO PEOPLE UNDER 18' -4='(-4) DON''T KNOW'
                  1='(1) 1 PERSON' 2='(2) 2 PEOPLE' 3='(3) 3 PEOPLE' 4='(4) 4 OR MORE PEOPLE' ;
  VALUE hh_size   -8='(-8) MISSING' -2='(-2) RESPONSE ILLEGIBLE'
                  1='(1) 2 PEOPLE INCLUDING MOTHER' 2='(2) 3 PEOPLE' 3='(3) 4 PEOPLE'
                  4='(4) 5 PEOPLE' 5='(5) 6 OR MORE PEOPLE' ;
  VALUE hrdprg    -8='(-8) MISSING' 1='(1) NONE' 2='(2) LESS THAN WEEKLY'
                  3='(3) WEEKLY OR MORE' ;
  VALUE m_anemia  -1='(-1) NO ABSTRACT DATA' 1='(1) ANEMIA NOTED IN CHART'
                  2='(2) ANEMIA NOT NOTED IN CHART' ;
  VALUE m_drug    -1='(-1) NO ABSTRACT DATA' 1='(1) DRUG ABUSE NOTED IN CHART'
                  2='(2) DRUG ABUSE NOT NOTED IN CHART' ;
  VALUE m_fdis    -1='(-1) NO ABSTRACT DATA' 1='(1) FETAL DISTRESS NOTED IN CHART'
                  2='(2) FETAL DISTRESS NOT NOTED IN CHART' ;
  VALUE m_gui     -1='(-1) NO ABSTRACT DATA'
                  1='(1) GENITOURINARY INFECTION NOTED IN CHART'
                  2='(2) GENITOURINARY INFECTION NOT NOTED IN CHART' ;
  VALUE m_hyper   -1='(-1) NO ABSTRACT DATA' 1='(1) HYPERTENSION NOTED IN CHART'
                  2='(2) HYPERTENSION NOT NOTED IN CHART' ;
  VALUE m_ipc     -1='(-1) NO ABSTRACT DATA' 1='(1) INSUFFICIENT PRENATAL CARE NOTED'
                  2='(2) INSUFFICIENT PRENATAL CARE NOT NOTED IN CHART' ;
  VALUE m_mental  -1='(-1) NO ABSTRACT DATA' 1='(1) MENTAL DISORDER NOTED IN CHART'
                  2='(2) MENTAL DISORDER NOT NOTED IN CHART' ;
  VALUE m_rupt    -1='(-1) NO ABSTRACT DATA'
                  1='(1) PREMATURE RUPTURE OF MEMBRANES NOTED IN CHART'
                  2='(2) PREMATURE RUPTURE OF MEMBRANES NOT NOTED IN CHART' ;
  VALUE m_vd      -1='(-1) NO ABSTRACT DATA' 1='(1) VENEREAL DISEASE NOTED IN CHART'
                  2='(2) VENEREAL DISEASE NOT NOTED IN CHART' ;
  VALUE marital   -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -6='(-6) MULTIPLE RESPONSE'
                  1='(1) SINGLE' 2='(2) MARRIED' 3='(3) WIDOWED/DIVORCED/SEPARATED' ;
  VALUE met_pay   -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' 1='(1) PRIVATE INSURANCE'
                  2='(2) MEDICAID' 3='(3) HMO' 4='(4) OTHER OR UNKNOWN' ;
  VALUE med_use   -8='(-8) MISSING' 1='(1) ANTIBIOTIC USE DURING PREGNANCY'
                  2='(2) NO ANTIBIOTIC USE DURING PREGNANCY' ;
  VALUE mrj_frq   -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 1='(1) NONE'
                  2='(2) LESS THAN WEEKLY' 3='(3) WEEKLY OR MORE' ;
  VALUE mrjflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE mrjmon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE mrjpreg   -8='(-8) MISSING' -6='(-6) DATA OUT OF RANGE' 0='(0) NO' 1='(1) YES' ;
  VALUE mrjyr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE nomjflag  -8='(-8) MISSING'
                  0='(0) NO (CRKFLAG,COCFLAG, HERFLAG, STMFLAG, STAFLAG NE 1)'
                  1='(1) YES(ANY CRKFLAG, COCFLAG, HERFLAG STMFLAG, STAFLAG=1)' ;
  VALUE nomjmon   -8='(-8) MISSING'
                  0='(0) NO (CRKMON, COCMON, HERMON, STMMON, STAMON NE 1)'
                  1='(1) YES(ANY CRKMON, COCMON, HERMON, STMMON, STAMON=1)' ;
  VALUE nomjpreg
                  0='(0) NO (ANY CRKPREG, COCPREG, HERPREG, STMPREG, STAPREG NE 1)'
                  1='(1) YES(ANY CRKPREG, COCPREG, HERPREG, STMPREG, STAPREG=1)' ;
  VALUE nomjyr    -8='(-8) MISSING'
                  0='(0) NO (ANY CRKYR, COCYR, HERYR, STMYR, STAYR NE 1)'
                  1='(1) YES(ANY CRKYR, COCYR, HERYR, STMYR, STAYR=1)' ;
  VALUE parity    -8='(-8) MISSING' 1='(1) NO PREVIOUS LIVE BIRTHS'
                  2='(2) ONE PREVIOUS LIVE BIRTH'
                  3='(3) TWO OR MORE PREVIOUS LIVE BIRTHS' ;
  VALUE pdrink    -8='(-8) MISSING' 0='(0) LESS THAN 100% PROBABILITY'
                  1='(1) 100% PROBABILITY' ;
  VALUE pn_care   1='(1) NO PRENATAL CARE' 2='(2) PRIVATE MD' 3='(3) HMO'
                  4='(4) HOSPITAL OUTPATIENT CLINIC'
                  5='(5) HEALTH DEPT/COMMUNITY CLINIC'
                  6='(6) OTHER OR UNKNOWN FACILITY' ;
  VALUE pn_num    1='(1) NO PRENATAL CARE' 2='(2) LESS THAN ONCE/MONTH'
                  3='(3) AT LEAST ONCE/MONTH, BUT NOT MORE'
                  4='(4) TWICE/MONTH OR MORE' 5='(5) UNKNOWN NUMBER OF VISITS' ;
  VALUE pn_tri    -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE'
                  -4='(-4) DON''T KNOW' 1='(1) FIRST TRIMESTER' 2='(2) SECOND TRIMESTER'
                  3='(3) THIRD TRIMESTER' ;
  VALUE pn_wk     -9='(-9) LEGITIMATE SKIP' -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE'
                  -4='(-4) DON''T KNOW' ;
  VALUE pr_use3f  -8='(-8) MISSING' 1='(1) NO DRUG, ALCOHOL, OR CIGARETTE USE'
                  2='(2) ALCOHOL AND/OR ALCOHOL USE, BUT NO DRUG USE'
                  3='(3) DRUG USE, WITH OR W/O CIGARETTES OR ALCOHOL' ;
  VALUE pr_use8f  -8='(-8) MISSING' 1='(1) NO DRUG, ALCOHOL, OR CIGARETTE USE'
                  2='(2) NO DRUG, OR ALCOHOL USE, BUT CIGARETTE USE'
                  3='(3) NO DRUG OR CIGARETTE USE, BUT ALCOHOL USE'
                  4='(4) NO DRUG USE, BUT BOTH ALCHL AND CIGARETTE USE'
                  5='(5) DRUG USE, BUT NO ALCOHOL OR CIGARETTE USE'
                  6='(6) DRUG AND CIGARETTE USE, BUT NO ALCOHOL USE'
                  7='(7) DRUG AND ALCOHOL USE, BUT NO CIGARETTE USE'
                  8='(8) DRUG, ALCOHOL, AND CIGARETTE USE' ;
  VALUE psyflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE psymon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE psypreg   0='(0) NO' 1='(1) YES' ;
  VALUE psyyr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE race      -8='(-8) MISSING' -6='(-6) MULTIPLE RESPONSE' 1='(1) WHITE' 2='(2) BLACK'
                  3='(3) HISPANIC' 4='(4) OTHER' ;
  VALUE reside    1='(1) DC RESIDENT' 2='(2) NON-DC RESIDENT' ;
  VALUE risklevf  -8='(-8) MISSING' -5='(-5) DATA OUT OF RANGE' 1='(1) HIGH RISK BABY(IES)'
                  2='(2) LOW RISK BABY(IES)' ;
  VALUE staflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE stamon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE stapreg   0='(0) NO' 1='(1) YES' ;
  VALUE stayr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE status    1='(1) NON-INTERVIEW' 2='(2) COMPLETED INTER., NO ABSTRACT DATA'
                  3='(3) COMPLETED INTER.,MO & BABY ABSTRACT'
                  4='(4) COMPLETED INTER.,MO ABSTRACT ONLY' ;
  VALUE stmflag   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE stmmon    -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE stmpreg   -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE stmyr     -8='(-8) MISSING' 0='(0) NO' 1='(1) YES' ;
  VALUE twins     1='(1) YES' 2='(2) NO' ;
  VALUE xage      -8='(-8) MISSING' -7='(-7) ITEM REFUSAL' -5='(-5) DATA OUT OF RANGE'
                  1='(1) 12-17 YEARS' 2='(2) 18-25 YEARS' 3='(3) 26-34 YEARS'
                  4='(4) 35+ YEARS' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (A_1 <= -1) THEN A_1 = .;
   IF (XA_1A <= -1) THEN XA_1A = .;
   IF (A_1B <= -1) THEN A_1B = .;
   IF (A_1C <= -1) THEN A_1C = .;
   IF (A_1D_01 <= -1) THEN A_1D_01 = .;
   IF (A_1D_02 <= -1) THEN A_1D_02 = .;
   IF (A_1D_03 <= -1) THEN A_1D_03 = .;
   IF (A_1D_04 <= -1) THEN A_1D_04 = .;
   IF (A_1D_05 <= -1) THEN A_1D_05 = .;
   IF (A_1D_06 <= -1) THEN A_1D_06 = .;
   IF (A_1D_07 <= -1) THEN A_1D_07 = .;
   IF (A_1D_08 <= -1) THEN A_1D_08 = .;
   IF (XA_2 <= -444) THEN XA_2 = .;
   IF (XA_3 <= -1) THEN XA_3 = .;
   IF (A_4 <= -1) THEN A_4 = .;
   IF (A4_A_1 <= -1) THEN A4_A_1 = .;
   IF (A4_A_2 <= -1) THEN A4_A_2 = .;
   IF (A_5 <= -1) THEN A_5 = .;
   IF (A_6 <= -1) THEN A_6 = .;
   IF (A_6A <= -1) THEN A_6A = .;
   IF (A_7_01 <= -1) THEN A_7_01 = .;
   IF (A_7_02 <= -1) THEN A_7_02 = .;
   IF (A_7_03 <= -1) THEN A_7_03 = .;
   IF (A_7_04 <= -1) THEN A_7_04 = .;
   IF (A_7_05 <= -1) THEN A_7_05 = .;
   IF (A_7_06 <= -1) THEN A_7_06 = .;
   IF (A_7_07 <= -1) THEN A_7_07 = .;
   IF (A_7_08 <= -1) THEN A_7_08 = .;
   IF (A_7_09 <= -1) THEN A_7_09 = .;
   IF (A_7_10 <= -1) THEN A_7_10 = .;
   IF (A_7_11 <= -1) THEN A_7_11 = .;
   IF (A_7_12 <= -1) THEN A_7_12 = .;
   IF (A_7_SP <= -1) THEN A_7_SP = .;
   IF (A_8_1 <= -1) THEN A_8_1 = .;
   IF (A_8A_1 <= -1) THEN A_8A_1 = .;
   IF (A_8_2 <= -1) THEN A_8_2 = .;
   IF (A_8A_2 <= -1) THEN A_8A_2 = .;
   IF (A_8_3 <= -1) THEN A_8_3 = .;
   IF (A_8A_3 <= -1) THEN A_8A_3 = .;
   IF (A_8_4 <= -1) THEN A_8_4 = .;
   IF (A_8A_4 <= -1) THEN A_8A_4 = .;
   IF (A_8_5 <= -1) THEN A_8_5 = .;
   IF (A_8A_5 <= -1) THEN A_8A_5 = .;
   IF (A_8_6 <= -1) THEN A_8_6 = .;
   IF (A_8A_6 <= -1) THEN A_8A_6 = .;
   IF (A_8_SP <= -1) THEN A_8_SP = .;
   IF (A_9 <= -1) THEN A_9 = .;
   IF (A_9_SP <= -1) THEN A_9_SP = .;
   IF (A_10 <= -1) THEN A_10 = .;
   IF (A_10_A <= -1) THEN A_10_A = .;
   IF (A_11 <= -1) THEN A_11 = .;
   IF (A_12 <= -1) THEN A_12 = .;
   IF (A_13_FT <= -1) THEN A_13_FT = .;
   IF (A_13_IN <= -1) THEN A_13_IN = .;
   IF (A_14 <= -1) THEN A_14 = .;
   IF (A_14_A <= -1) THEN A_14_A = .;
   IF (A_14_C <= -1) THEN A_14_C = .;
   IF (A_15_A <= -1) THEN A_15_A = .;
   IF (A_15_B <= -1) THEN A_15_B = .;
   IF (A_15_C <= -1) THEN A_15_C = .;
   IF (A_15_D <= -1) THEN A_15_D = .;
   IF (A17A1_LB <= -1) THEN A17A1_LB = .;
   IF (A17A1_OZ <= -1) THEN A17A1_OZ = .;
   IF (XA17A1 <= -1) THEN XA17A1 = .;
   IF (A17A1_MF <= -1) THEN A17A1_MF = .;
   IF (A17A1_YN <= -1) THEN A17A1_YN = .;
   IF (A17A2_LB <= -1) THEN A17A2_LB = .;
   IF (A17A2_OZ <= -1) THEN A17A2_OZ = .;
   IF (XA17A2 <= -1) THEN XA17A2 = .;
   IF (A17A2_MF <= -1) THEN A17A2_MF = .;
   IF (A17A2_YN <= -1) THEN A17A2_YN = .;
   IF (A17A3_LB <= -1) THEN A17A3_LB = .;
   IF (A17A3_OZ <= -1) THEN A17A3_OZ = .;
   IF (XA17A3 <= -1) THEN XA17A3 = .;
   IF (A17A3_MF <= -1) THEN A17A3_MF = .;
   IF (A17A3_YN <= -1) THEN A17A3_YN = .;
   IF (A17A4_LB <= -1) THEN A17A4_LB = .;
   IF (A17A4_OZ <= -1) THEN A17A4_OZ = .;
   IF (XA17A4 <= -1) THEN XA17A4 = .;
   IF (A17A4_MF <= -1) THEN A17A4_MF = .;
   IF (A17A4_YN <= -1) THEN A17A4_YN = .;
   IF (A17A5_LB <= -1) THEN A17A5_LB = .;
   IF (A17A5_OZ <= -1) THEN A17A5_OZ = .;
   IF (XA17A5 <= -1) THEN XA17A5 = .;
   IF (A17A5_MF <= -1) THEN A17A5_MF = .;
   IF (A17A5_YN <= -1) THEN A17A5_YN = .;
   IF (A17A6_LB <= -1) THEN A17A6_LB = .;
   IF (A17A6_OZ <= -1) THEN A17A6_OZ = .;
   IF (XA17A6 <= -1) THEN XA17A6 = .;
   IF (A17A6_MF <= -1) THEN A17A6_MF = .;
   IF (A17A6_YN <= -1) THEN A17A6_YN = .;
   IF (A17A7_LB <= -1) THEN A17A7_LB = .;
   IF (A17A7_OZ <= -1) THEN A17A7_OZ = .;
   IF (XA17A7 <= -1) THEN XA17A7 = .;
   IF (A17A7_MF <= -1) THEN A17A7_MF = .;
   IF (A17A7_YN <= -1) THEN A17A7_YN = .;
   IF (A17A8_LB <= -1) THEN A17A8_LB = .;
   IF (A17A8_OZ <= -1) THEN A17A8_OZ = .;
   IF (XA17A8 <= -1) THEN XA17A8 = .;
   IF (A17A8_MF <= -1) THEN A17A8_MF = .;
   IF (A17A8_YN <= -1) THEN A17A8_YN = .;
   IF (A17A9_LB <= -1) THEN A17A9_LB = .;
   IF (A17A9_OZ <= -1) THEN A17A9_OZ = .;
   IF (XA17A9 <= -1) THEN XA17A9 = .;
   IF (A17A9_MF <= -1) THEN A17A9_MF = .;
   IF (A17A9_YN <= -1) THEN A17A9_YN = .;
   IF (XAGECALC <= -1) THEN XAGECALC = .;
   IF (B_2 <= -1) THEN B_2 = .;
   IF (B_3 <= -1) THEN B_3 = .;
   IF (B_4 <= -1) THEN B_4 = .;
   IF (B_5 <= -1) THEN B_5 = .;
   IF (B_6 <= -1) THEN B_6 = .;
   IF (B_7 <= -1) THEN B_7 = .;
   IF (C_1 <= -1) THEN C_1 = .;
   IF (C_2 <= -1) THEN C_2 = .;
   IF (C_3 <= -1) THEN C_3 = .;
   IF (C_4 <= -1) THEN C_4 = .;
   IF (C_5 <= -1) THEN C_5 = .;
   IF (C_6 <= -1) THEN C_6 = .;
   IF (C_7 <= -1) THEN C_7 = .;
   IF (C_8 <= -1) THEN C_8 = .;
   IF (C_9 <= -1) THEN C_9 = .;
   IF (C_10 <= -1) THEN C_10 = .;
   IF (C_11 <= -1) THEN C_11 = .;
   IF (C_12 <= -1) THEN C_12 = .;
   IF (C_13 <= -1) THEN C_13 = .;
   IF (C_14 <= -1) THEN C_14 = .;
   IF (C_15 <= -1) THEN C_15 = .;
   IF (C_16 <= -1) THEN C_16 = .;
   IF (C_17 <= -1) THEN C_17 = .;
   IF (C_18 <= -1) THEN C_18 = .;
   IF (C_19 <= -1) THEN C_19 = .;
   IF (C_20 <= -1) THEN C_20 = .;
   IF (C_21 <= -1) THEN C_21 = .;
   IF (C_22 <= -1) THEN C_22 = .;
   IF (C_23 <= -1) THEN C_23 = .;
   IF (C_24 <= -1) THEN C_24 = .;
   IF (C_25 <= -1) THEN C_25 = .;
   IF (C_26 <= -1) THEN C_26 = .;
   IF (C_27 <= -1) THEN C_27 = .;
   IF (C_28 <= -1) THEN C_28 = .;
   IF (C_29_01 <= -1) THEN C_29_01 = .;
   IF (C_29_02 <= -1) THEN C_29_02 = .;
   IF (C_29_03 <= -1) THEN C_29_03 = .;
   IF (C_29_04 <= -1) THEN C_29_04 = .;
   IF (C_29_05 <= -1) THEN C_29_05 = .;
   IF (C_29_91 <= -1) THEN C_29_91 = .;
   IF (C_30 <= -1) THEN C_30 = .;
   IF (C_31 <= -1) THEN C_31 = .;
   IF (C_32 <= -1) THEN C_32 = .;
   IF (C_33 <= -1) THEN C_33 = .;
   IF (C_34 <= -1) THEN C_34 = .;
   IF (C_35 <= -1) THEN C_35 = .;
   IF (D_1_01 <= -1) THEN D_1_01 = .;
   IF (D_1_02 <= -1) THEN D_1_02 = .;
   IF (D_1_03 <= -1) THEN D_1_03 = .;
   IF (D_1_04 <= -1) THEN D_1_04 = .;
   IF (D_1_05 <= -1) THEN D_1_05 = .;
   IF (D_1_06 <= -1) THEN D_1_06 = .;
   IF (D_1_07 <= -1) THEN D_1_07 = .;
   IF (D_1_08 <= -1) THEN D_1_08 = .;
   IF (D_1_09 <= -1) THEN D_1_09 = .;
   IF (D_1_10 <= -1) THEN D_1_10 = .;
   IF (D_1_11 <= -1) THEN D_1_11 = .;
   IF (D_1_12 <= -1) THEN D_1_12 = .;
   IF (D_1_13 <= -1) THEN D_1_13 = .;
   IF (D_1_14 <= -1) THEN D_1_14 = .;
   IF (D_1_15 <= -1) THEN D_1_15 = .;
   IF (D_1_16 <= -1) THEN D_1_16 = .;
   IF (D_1_91 <= -1) THEN D_1_91 = .;
   IF (D_2 <= -1) THEN D_2 = .;
   IF (D_3 <= -1) THEN D_3 = .;
   IF (D_4 <= -1) THEN D_4 = .;
   IF (D_5_A <= -1) THEN D_5_A = .;
   IF (D_5_B <= -1) THEN D_5_B = .;
   IF (D_5_C <= -1) THEN D_5_C = .;
   IF (D_5_D <= -1) THEN D_5_D = .;
   IF (D_5_E <= -1) THEN D_5_E = .;
   IF (E_1 <= -1) THEN E_1 = .;
   IF (E_2 <= -1) THEN E_2 = .;
   IF (E_3 <= -1) THEN E_3 = .;
   IF (E_4 <= -1) THEN E_4 = .;
   IF (F_1_A <= -1) THEN F_1_A = .;
   IF (F_1_B <= -1) THEN F_1_B = .;
   IF (F_2_A <= -1) THEN F_2_A = .;
   IF (F_2_B <= -1) THEN F_2_B = .;
   IF (F_3_A <= -1) THEN F_3_A = .;
   IF (F_3_B <= -1) THEN F_3_B = .;
   IF (F_4_A <= -1) THEN F_4_A = .;
   IF (F_4_B <= -1) THEN F_4_B = .;
   IF (F_5_A <= -1) THEN F_5_A = .;
   IF (F_5_B <= -1) THEN F_5_B = .;
   IF (F_6_A <= -1) THEN F_6_A = .;
   IF (F_6_B <= -1) THEN F_6_B = .;
   IF (F_7_A <= -1) THEN F_7_A = .;
   IF (F_7_B <= -1) THEN F_7_B = .;
   IF (F_8_A <= -1) THEN F_8_A = .;
   IF (F_8_B <= -1) THEN F_8_B = .;
   IF (F_8_A_A <= -1) THEN F_8_A_A = .;
   IF (F_8_A_B <= -1) THEN F_8_A_B = .;
   IF (F_9 <= -1) THEN F_9 = .;
   IF (F_10 <= -1) THEN F_10 = .;
   IF (G_1 <= -1) THEN G_1 = .;
   IF (G_2_INCO <= -1) THEN G_2_INCO = .;
   IF (G_3_1 <= -1) THEN G_3_1 = .;
   IF (G_3_2 <= -1) THEN G_3_2 = .;
   IF (G_3_4 <= -1) THEN G_3_4 = .;
   IF (G_3_5 <= -1) THEN G_3_5 = .;
   IF (G_3_6 <= -1) THEN G_3_6 = .;
   IF (G_3_7 <= -1) THEN G_3_7 = .;
   IF (G_3_8 <= -1) THEN G_3_8 = .;
   IF (G_3_9 <= -1) THEN G_3_9 = .;
   IF (G_3_10 <= -1) THEN G_3_10 = .;
   IF (G_3_11 <= -1) THEN G_3_11 = .;
   IF (G_3_SP <= -1) THEN G_3_SP = .;
   IF (H_1 <= -1) THEN H_1 = .;
   IF (H_2 <= -1) THEN H_2 = .;
   IF (H_3 <= -1) THEN H_3 = .;
   IF (H_4_1 <= -1) THEN H_4_1 = .;
   IF (H_4_2 <= -1) THEN H_4_2 = .;
   IF (H_4_3 <= -1) THEN H_4_3 = .;
   IF (H_4_4 <= -1) THEN H_4_4 = .;
   IF (H_5_A <= -1) THEN H_5_A = .;
   IF (H_5_B <= -1) THEN H_5_B = .;
   IF (H_5_C <= -1) THEN H_5_C = .;
   IF (H_6 <= -1) THEN H_6 = .;
   IF (H_6_SP <= -1) THEN H_6_SP = .;
   IF (MCOMPMN <= -1) THEN MCOMPMN = .;
   IF (XMOMAGE <= -1) THEN XMOMAGE = .;
   IF (M2RACE <= -1) THEN M2RACE = .;
   IF (M2_OTH <= -1) THEN M2_OTH = .;
   IF (XM3ADM <= -1) THEN XM3ADM = .;
   IF (M4PAY <= -1) THEN M4PAY = .;
   IF (M5_01A <= -1) THEN M5_01A = .;
   IF (M5_02A <= -1) THEN M5_02A = .;
   IF (M5_03A <= -1) THEN M5_03A = .;
   IF (M5_04A <= -1) THEN M5_04A = .;
   IF (M5_05A <= -1) THEN M5_05A = .;
   IF (M5_06A <= -1) THEN M5_06A = .;
   IF (M5_07A <= -1) THEN M5_07A = .;
   IF (M5_08A <= -1) THEN M5_08A = .;
   IF (M5_09A <= -1) THEN M5_09A = .;
   IF (M5_10A <= -1) THEN M5_10A = .;
   IF (XM6DIS <= -1) THEN XM6DIS = .;
   IF (M7DISPO <= -1) THEN M7DISPO = .;
   IF (M8REFER <= -1) THEN M8REFER = .;
   IF (M8_OTH <= -1) THEN M8_OTH = .;
   IF (M9LABOR <= -1) THEN M9LABOR = .;
   IF (M10DEL <= -1) THEN M10DEL = .;
   IF (M11ANEM <= -1) THEN M11ANEM = .;
   IF (M12GES <= -1) THEN M12GES = .;
   IF (M13DIA <= -1) THEN M13DIA = .;
   IF (M14HRT <= -1) THEN M14HRT = .;
   IF (M15HIV <= -1) THEN M15HIV = .;
   IF (M16HYP <= -1) THEN M16HYP = .;
   IF (M17SKL <= -1) THEN M17SKL = .;
   IF (M18STD <= -1) THEN M18STD = .;
   IF (M19ACAF <= -1) THEN M19ACAF = .;
   IF (M19BTOB <= -1) THEN M19BTOB = .;
   IF (M19CMAR <= -1) THEN M19CMAR = .;
   IF (M19DALC <= -1) THEN M19DALC = .;
   IF (M19EAMP <= -1) THEN M19EAMP = .;
   IF (M19FHER <= -1) THEN M19FHER = .;
   IF (M19GOPI <= -1) THEN M19GOPI = .;
   IF (M19HMET <= -1) THEN M19HMET = .;
   IF (M19ICRK <= -1) THEN M19ICRK = .;
   IF (M19JCOC <= -1) THEN M19JCOC = .;
   IF (M19KPCP <= -1) THEN M19KPCP = .;
   IF (M20EVID <= -1) THEN M20EVID = .;
   IF (M21ARSLT <= -1) THEN M21ARSLT = .;
   IF (M21BRSLT <= -1) THEN M21BRSLT = .;
   IF (M21CRSLT <= -1) THEN M21CRSLT = .;
   IF (M21DRSLT <= -1) THEN M21DRSLT = .;
   IF (M21ERSLT <= -1) THEN M21ERSLT = .;
   IF (MBOXA_A1 <= -1) THEN MBOXA_A1 = .;
   IF (MBOXA_A2 <= -1) THEN MBOXA_A2 = .;
   IF (MSPECPRO <= -1) THEN MSPECPRO = .;
   IF (M5CNTR <= -1) THEN M5CNTR = .;
   IF (A_EDUC <= -1) THEN A_EDUC = .;
   IF (AGE <= -1) THEN AGE = .;
   IF (AGE_YR <= -1) THEN AGE_YR = .;
   IF (ALC_AMT <= -1) THEN ALC_AMT = .;
   IF (ALC_AMT3 <= -1) THEN ALC_AMT3 = .;
   IF (ALC_CAT <= -1) THEN ALC_CAT = .;
   IF (ALC_DAY <= -1) THEN ALC_DAY = .;
   IF (ALCFLAG <= -1) THEN ALCFLAG = .;
   IF (ALCMON <= -1) THEN ALCMON = .;
   IF (ALCPREG <= -1) THEN ALCPREG = .;
   IF (ALCYR <= -1) THEN ALCYR = .;
   IF (ANYBWG <= -1) THEN ANYBWG = .;
   IF (ANYBWT <= -1) THEN ANYBWT = .;
   IF (ANYCARE <= -1) THEN ANYCARE = .;
   IF (ANYFLAG <= -1) THEN ANYFLAG = .;
   IF (ANYMON <= -1) THEN ANYMON = .;
   IF (ANYPREG <= -1) THEN ANYPREG = .;
   IF (ANYYR <= -1) THEN ANYYR = .;
   IF (AV_ETHAN <= -1) THEN AV_ETHAN = .;
   IF (CIG_AMT <= -1) THEN CIG_AMT = .;
   IF (CIGFLAG <= -1) THEN CIGFLAG = .;
   IF (CIGMON <= -1) THEN CIGMON = .;
   IF (CIGPREG <= -1) THEN CIGPREG = .;
   IF (CIGYR <= -1) THEN CIGYR = .;
   IF (COCFLAG <= -1) THEN COCFLAG = .;
   IF (COCMON <= -1) THEN COCMON = .;
   IF (COCPREG <= -1) THEN COCPREG = .;
   IF (COCYR <= -1) THEN COCYR = .;
   IF (COO_FRQ <= -1) THEN COO_FRQ = .;
   IF (COOFLAG <= -1) THEN COOFLAG = .;
   IF (COOMON <= -1) THEN COOMON = .;
   IF (COOPREG <= -1) THEN COOPREG = .;
   IF (COOYR <= -1) THEN COOYR = .;
   IF (CONTRA <= -1) THEN CONTRA = .;
   IF (CRK_FRQ <= -1) THEN CRK_FRQ = .;
   IF (CRKFLAG <= -1) THEN CRKFLAG = .;
   IF (CRKMON <= -1) THEN CRKMON = .;
   IF (CRKPREG <= -1) THEN CRKPREG = .;
   IF (CRKYR <= -1) THEN CRKYR = .;
   IF (G3_GOVT <= -1) THEN G3_GOVT = .;
   IF (G3_NONE <= -1) THEN G3_NONE = .;
   IF (G3_OTH <= -1) THEN G3_OTH = .;
   IF (HERFLAG <= -1) THEN HERFLAG = .;
   IF (HERMON <= -1) THEN HERMON = .;
   IF (HERPREG <= -1) THEN HERPREG = .;
   IF (HERYR <= -1) THEN HERYR = .;
   IF (HH_INC <= -1) THEN HH_INC = .;
   IF (HH_SIZ18 <= -1) THEN HH_SIZ18 = .;
   IF (HH_SIZE <= -1) THEN HH_SIZE = .;
   IF (HRDPRG <= -1) THEN HRDPRG = .;
   IF (M_ANEMIA <= -1) THEN M_ANEMIA = .;
   IF (M_DRUG <= -1) THEN M_DRUG = .;
   IF (M_FDIS <= -1) THEN M_FDIS = .;
   IF (M_GUI <= -1) THEN M_GUI = .;
   IF (M_HYPER <= -1) THEN M_HYPER = .;
   IF (M_IPC <= -1) THEN M_IPC = .;
   IF (M_MENTAL <= -1) THEN M_MENTAL = .;
   IF (M_RUPT <= -1) THEN M_RUPT = .;
   IF (M_VD <= -1) THEN M_VD = .;
   IF (MARITAL <= -1) THEN MARITAL = .;
   IF (MET_PAY <= -1) THEN MET_PAY = .;
   IF (MED_USE <= -1) THEN MED_USE = .;
   IF (MRJ_FRQ <= -1) THEN MRJ_FRQ = .;
   IF (MRJFLAG <= -1) THEN MRJFLAG = .;
   IF (MRJMON <= -1) THEN MRJMON = .;
   IF (MRJPREG <= -1) THEN MRJPREG = .;
   IF (MRJYR <= -1) THEN MRJYR = .;
   IF (NOMJFLAG <= -1) THEN NOMJFLAG = .;
   IF (NOMJMON <= -1) THEN NOMJMON = .;
   IF (NOMJPREG <= -1) THEN NOMJPREG = .;
   IF (NOMJYR <= -1) THEN NOMJYR = .;
   IF (PARITY <= -1) THEN PARITY = .;
   IF (PDRINK <= -1) THEN PDRINK = .;
   IF (PN_CARE <= -1) THEN PN_CARE = .;
   IF (PN_NUM <= -1) THEN PN_NUM = .;
   IF (PN_TRI <= -1) THEN PN_TRI = .;
   IF (PN_WK <= -1) THEN PN_WK = .;
   IF (PR_USE3 <= -1) THEN PR_USE3 = .;
   IF (PR_USE8 <= -1) THEN PR_USE8 = .;
   IF (PSYFLAG <= -1) THEN PSYFLAG = .;
   IF (PSYMON <= -1) THEN PSYMON = .;
   IF (PSYPREG <= -1) THEN PSYPREG = .;
   IF (PSYYR <= -1) THEN PSYYR = .;
   IF (RACE <= -1) THEN RACE = .;
   IF (RESIDE <= -1) THEN RESIDE = .;
   IF (RISKLEV2 <= -1) THEN RISKLEV2 = .;
   IF (STAFLAG <= -1) THEN STAFLAG = .;
   IF (STAMON <= -1) THEN STAMON = .;
   IF (STAPREG <= -1) THEN STAPREG = .;
   IF (STAYR <= -1) THEN STAYR = .;
   IF (STATUS <= -1) THEN STATUS = .;
   IF (STMFLAG <= -1) THEN STMFLAG = .;
   IF (STMMON <= -1) THEN STMMON = .;
   IF (STMPREG <= -1) THEN STMPREG = .;
   IF (STMYR <= -1) THEN STMYR = .;
   IF (TWINS <= -1) THEN TWINS = .;
   IF (XAGE <= -1) THEN XAGE = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT SPANISH spanish. A_1 a_1fffff. XA_1A xa_1a.
         A_1B a_1b. A_1C a_1c. A_1D_01 a_1d_01f.
         A_1D_02 a_1d_02f. A_1D_03 a_1d_03f. A_1D_04 a_1d_04f.
         A_1D_05 a_1d_05f. A_1D_06 a_1d_06f. A_1D_07 a_1d_07f.
         A_1D_08 a_1d_08f. XA_2 xa_2ffff. XA_3 xa_3ffff.
         A_4 a_4fffff. A4_A_1 a4_a_1ff. A4_A_2 a4_a_2ff.
         A_5 a_5fffff. A_6 a_6fffff. A_6A a_6a.
         A_7_01 a_7_01ff. A_7_02 a_7_02ff. A_7_03 a_7_03ff.
         A_7_04 a_7_04ff. A_7_05 a_7_05ff. A_7_06 a_7_06ff.
         A_7_07 a_7_07ff. A_7_08 a_7_08ff. A_7_09 a_7_09ff.
         A_7_10 a_7_10ff. A_7_11 a_7_11ff. A_7_12 a_7_12ff.
         A_7_SP a_7_sp. A_8_1 a_8_1fff. A_8A_1 a_8a_1ff.
         A_8_2 a_8_2fff. A_8A_2 a_8a_2ff. A_8_3 a_8_3fff.
         A_8A_3 a_8a_3ff. A_8_4 a_8_4fff. A_8A_4 a_8a_4ff.
         A_8_5 a_8_5fff. A_8A_5 a_8a_5ff. A_8_6 a_8_6fff.
         A_8A_6 a_8a_6ff. A_8_SP a_8_sp. A_9 a_9fffff.
         A_9_SP a_9_sp. A_10 a_10ffff. A_10_A a_10_a.
         A_11 a_11ffff. A_12 a_12ffff. A_13_FT a_13_ft.
         A_13_IN a_13_in. A_14 a_14ffff. A_14_A a_14_a.
         A_14_C a_14_c. A_15_A a_15_a. A_15_B a_15_b.
         A_15_C a_15_c. A_15_D a_15_d. A17A1_LB a17a1_lb.
         A17A1_OZ a17a1_oz. XA17A1 xa17a1ff. A17A1_MF a17a1_mf.
         A17A1_YN a17a1_yn. A17A2_LB a17a2_lb. A17A2_OZ a17a2_oz.
         XA17A2 xa17a2ff. A17A2_MF a17a2_mf. A17A2_YN a17a2_yn.
         A17A3_LB a17a3_lb. A17A3_OZ a17a3_oz. XA17A3 xa17a3ff.
         A17A3_MF a17a3_mf. A17A3_YN a17a3_yn. A17A4_LB a17a4_lb.
         A17A4_OZ a17a4_oz. XA17A4 xa17a4ff. A17A4_MF a17a4_mf.
         A17A4_YN a17a4_yn. A17A5_LB a17a5_lb. A17A5_OZ a17a5_oz.
         XA17A5 xa17a5ff. A17A5_MF a17a5_mf. A17A5_YN a17a5_yn.
         A17A6_LB a17a6_lb. A17A6_OZ a17a6_oz. XA17A6 xa17a6ff.
         A17A6_MF a17a6_mf. A17A6_YN a17a6_yn. A17A7_LB a17a7_lb.
         A17A7_OZ a17a7_oz. XA17A7 xa17a7ff. A17A7_MF a17a7_mf.
         A17A7_YN a17a7_yn. A17A8_LB a17a8_lb. A17A8_OZ a17a8_oz.
         XA17A8 xa17a8ff. A17A8_MF a17a8_mf. A17A8_YN a17a8_yn.
         A17A9_LB a17a9_lb. A17A9_OZ a17a9_oz. XA17A9 xa17a9ff.
         A17A9_MF a17a9_mf. A17A9_YN a17a9_yn. XAGECALC xagecalc.
         B_2 b_2fffff. B_3 b_3fffff. B_4 b_4fffff.
         B_5 b_5fffff. B_6 b_6fffff. B_7 b_7fffff.
         C_1 c_1fffff. C_2 c_2fffff. C_3 c_3fffff.
         C_4 c_4fffff. C_5 c_5fffff. C_6 c_6fffff.
         C_7 c_7fffff. C_8 c_8fffff. C_9 c_9fffff.
         C_10 c_10ffff. C_11 c_11ffff. C_12 c_12ffff.
         C_13 c_13ffff. C_14 c_14ffff. C_15 c_15ffff.
         C_16 c_16ffff. C_17 c_17ffff. C_18 c_18ffff.
         C_19 c_19ffff. C_20 c_20ffff. C_21 c_21ffff.
         C_22 c_22ffff. C_23 c_23ffff. C_24 c_24ffff.
         C_25 c_25ffff. C_26 c_26ffff. C_27 c_27ffff.
         C_28 c_28ffff. C_29_01 c_29_01f. C_29_02 c_29_02f.
         C_29_03 c_29_03f. C_29_04 c_29_04f. C_29_05 c_29_05f.
         C_29_91 c_29_91f. C_30 c_30ffff. C_31 c_31ffff.
         C_32 c_32ffff. C_33 c_33ffff. C_34 c_34ffff.
         C_35 c_35ffff. D_1_01 d_1_01ff. D_1_02 d_1_02ff.
         D_1_03 d_1_03ff. D_1_04 d_1_04ff. D_1_05 d_1_05ff.
         D_1_06 d_1_06ff. D_1_07 d_1_07ff. D_1_08 d_1_08ff.
         D_1_09 d_1_09ff. D_1_10 d_1_10ff. D_1_11 d_1_11ff.
         D_1_12 d_1_12ff. D_1_13 d_1_13ff. D_1_14 d_1_14ff.
         D_1_15 d_1_15ff. D_1_16 d_1_16ff. D_1_91 d_1_91ff.
         D_2 d_2fffff. D_3 d_3fffff. D_4 d_4fffff.
         D_5_A d_5_a. D_5_B d_5_b. D_5_C d_5_c.
         D_5_D d_5_d. D_5_E d_5_e. E_1 e_1fffff.
         E_2 e_2fffff. E_3 e_3fffff. E_4 e_4fffff.
         F_1_A f_1_a. F_1_B f_1_b. F_2_A f_2_a.
         F_2_B f_2_b. F_3_A f_3_a. F_3_B f_3_b.
         F_4_A f_4_a. F_4_B f_4_b. F_5_A f_5_a.
         F_5_B f_5_b. F_6_A f_6_a. F_6_B f_6_b.
         F_7_A f_7_a. F_7_B f_7_b. F_8_A f_8_a.
         F_8_B f_8_b. F_8_A_A f_8_a_a. F_8_A_B f_8_a_b.
         F_9 f_9fffff. F_10 f_10ffff. G_1 g_1fffff.
         G_2_INCO g_2_inco. G_3_1 g_3_1fff. G_3_2 g_3_2fff.
         G_3_4 g_3_4fff. G_3_5 g_3_5fff. G_3_6 g_3_6fff.
         G_3_7 g_3_7fff. G_3_8 g_3_8fff. G_3_9 g_3_9fff.
         G_3_10 g_3_10ff. G_3_11 g_3_11ff. G_3_SP g_3_sp.
         H_1 h_1fffff. H_2 h_2fffff. H_3 h_3fffff.
         H_4_1 h_4_1fff. H_4_2 h_4_2fff. H_4_3 h_4_3fff.
         H_4_4 h_4_4fff. H_5_A h_5_a. H_5_B h_5_b.
         H_5_C h_5_c. H_6 h_6fffff. H_6_SP h_6_sp.
         MCOMPMN mcompmn. XMOMAGE xmomage. M2RACE m2race.
         M2_OTH m2_oth. XM3ADM xm3adm. M4PAY m4pay.
         M5_01A m5_01a. M5_02A m5_02a. M5_03A m5_03a.
         M5_04A m5_04a. M5_05A m5_05a. M5_06A m5_06a.
         M5_07A m5_07a. M5_08A m5_08a. M5_09A m5_09a.
         M5_10A m5_10a. XM6DIS xm6dis. M7DISPO m7dispo.
         M8REFER m8refer. M8_OTH m8_oth. M9LABOR m9labor.
         M10DEL m10del. M11ANEM m11anem. M12GES m12ges.
         M13DIA m13dia. M14HRT m14hrt. M15HIV m15hiv.
         M16HYP m16hyp. M17SKL m17skl. M18STD m18std.
         M19ACAF m19acaf. M19BTOB m19btob. M19CMAR m19cmar.
         M19DALC m19dalc. M19EAMP m19eamp. M19FHER m19fher.
         M19GOPI m19gopi. M19HMET m19hmet. M19ICRK m19icrk.
         M19JCOC m19jcoc. M19KPCP m19kpcp. M20EVID m20evid.
         M21ARSLT m21arslt. M21BRSLT m21brslt. M21CRSLT m21crslt.
         M21DRSLT m21drslt. M21ERSLT m21erslt. MBOXA_A1 mboxa_af.
         MBOXA_A2 mboxa_0f. MSPECPRO mspecpro. M5CNTR m5cntr.
         A_EDUC a_educ. AGE age. AGE_YR age_yr.
         ALC_AMT alc_amt. ALC_AMT3 alc_amtf. ALC_CAT alc_cat.
         ALC_DAY alc_day. ALCFLAG alcflag. ALCMON alcmon.
         ALCPREG alcpreg. ALCYR alcyr. ANYBWG anybwg.
         ANYBWT anybwt. ANYCARE anycare. ANYFLAG anyflag.
         ANYMON anymon. ANYPREG anypreg. ANYYR anyyr.
         AV_ETHAN av_ethan. CIG_AMT cig_amt. CIGFLAG cigflag.
         CIGMON cigmon. CIGPREG cigpreg. CIGYR cigyr.
         COCFLAG cocflag. COCMON cocmon. COCPREG cocpreg.
         COCYR cocyr. COO_FRQ coo_frq. COOFLAG cooflag.
         COOMON coomon. COOPREG coopreg. COOYR cooyr.
         CONTRA contra. CRK_FRQ crk_frq. CRKFLAG crkflag.
         CRKMON crkmon. CRKPREG crkpreg. CRKYR crkyr.
         G3_GOVT g3_govt. G3_NONE g3_none. G3_OTH g3_oth.
         HERFLAG herflag. HERMON hermon. HERPREG herpreg.
         HERYR heryr. HH_INC hh_inc. HH_SIZ18 hh_siz1f.
         HH_SIZE hh_size. HRDPRG hrdprg. M_ANEMIA m_anemia.
         M_DRUG m_drug. M_FDIS m_fdis. M_GUI m_gui.
         M_HYPER m_hyper. M_IPC m_ipc. M_MENTAL m_mental.
         M_RUPT m_rupt. M_VD m_vd. MARITAL marital.
         MET_PAY met_pay. MED_USE med_use. MRJ_FRQ mrj_frq.
         MRJFLAG mrjflag. MRJMON mrjmon. MRJPREG mrjpreg.
         MRJYR mrjyr. NOMJFLAG nomjflag. NOMJMON nomjmon.
         NOMJPREG nomjpreg. NOMJYR nomjyr. PARITY parity.
         PDRINK pdrink. PN_CARE pn_care. PN_NUM pn_num.
         PN_TRI pn_tri. PN_WK pn_wk. PR_USE3 pr_use3f.
         PR_USE8 pr_use8f. PSYFLAG psyflag. PSYMON psymon.
         PSYPREG psypreg. PSYYR psyyr. RACE race.
         RESIDE reside. RISKLEV2 risklevf. STAFLAG staflag.
         STAMON stamon. STAPREG stapreg. STAYR stayr.
         STATUS status. STMFLAG stmflag. STMMON stmmon.
         STMPREG stmpreg. STMYR stmyr. TWINS twins.
         XAGE xage.  ;

RUN ;
